=head1 NAME

IRC::Bot::Hangman::WordList::Default - Default word list

=head1 SYNOPSIS

See IRC::Bot::Hangman

=head1 DESCRIPTION

This module provides the default word list

A word list plugin is basically a method name()
and a __DATA__ section containing the words.

=cut

package IRC::Bot::Hangman::WordList::Default;
use warnings::register;
use strict;


=head1 METHODS

=head2 name()

This plugin name - 'default'

=cut

sub name () { 'default' }



1;


=head1 AUTHOR

Pierre Denis <pierre@itrelease.net>

http://www.itrelease.net/

=head1 COPYRIGHT

Copyright 2005 IT Release Ltd - All Rights Reserved.

This module is released under the same license as Perl itself.

=cut


__DATA__
abases
abductor
aberration
abrogate
absolutes
absorbency
absurd
abused
acacia
accelerates
accessible
accident
accidentally
acclaimed
acclimate
acclimatisation
accomplishments
accosts
accredited
accrued
acquaints
acquiescent
acreages
acrobatic
acrostics
acrylic
adaptable
adaptations
addicted
admits
adorable
adrenal
adulation
adventurer
aerosol
affirmatively
affirmed
afternoons
afterwards
aggregating
agnostics
agonize
agreeing
airless
airworthy
allergic
alphabetize
alright
alternatively
amalgams
amateurish
ambassadors
amenities
amidst
ampoules
amusements
anachronistically
analgesic
analysed
analysing
analysis
analyst
anecdotal
anesthetizing
angered
angioplasties
anglicisms
angoras
annihilate
annihilates
antagonises
antedated
anticipating
anticlimactic
antirrhinums
apologized
apotheoses
appall
appertains
appetizers
appraisals
appreciations
apprehended
apprehending
apprehensive
approved
arabesque
arcade
archaeological
archetypical
arraying
arrives
arrogance
arterial
ascetics
ascribes
asphalted
aspirate
assassinating
assenting
assents
assessing
assuage
asunder
asylum
atelier
atheists
attacking
attesting
attributing
auburn
audibility
audiovisual
authorship
autographing
autographs
automated
autopilots
available
avenge
avenged
averagely
averting
aviary
avionics
awakened
awkward
awoken
bagging
bagpipe
baguettes
bandleader
bandstand
baptisms
barbie
barefooted
barney
barneys
barometers
baronets
bartering
battering
batterings
batting
battleaxe
battlefields
bauxite
bazaar
beagles
beautiful
bedroom
bedsitter
beefsteaks
befitted
behaviour
behooves
belabors
belaying
believable
bellboy
bemoans
benighted
bequest
beseechingly
bespoke
bested
betrays
betrothed
betwixt
bibliography
bibliophiles
biggie
billboard
binning
birdbrains
birthplace
blackened
blackest
blacksmiths
blamed
blancmanges
blanket
blared
bleaching
blotched
blowups
blunted
blunter
boaters
bobbins
boltholes
bombard
bonnier
bonuses
boogied
bookable
bookbinding
bookmark
booksellers
bookworms
boosts
bootlace
bottoms
bouffant
brainstorm
breakfast
breakups
breaststroke
brigades
brightly
brings
briskly
broadcaster
broadens
brouhaha
brutal
brutality
brutally
buffalo
buffoons
bugbear
bullied
bullring
buoyantly
bureaucratic
burglaries
burgundies
busied
buzzword
caddied
cajole
calories
campaigner
campaigners
camping
canapes
cancels
canonise
canoodling
canvas
captain
captives
caramelise
caravanning
cardamoms
careering
carnation
carnations
carpeted
carting
casually
categorizing
ceding
celebratory
cenotaphs
censures
centerpiece
centiliter
centimetre
chainsaws
challenges
chamomile
chances
chapels
characterizations
characters
charades
chaser
chattered
cheapen
chickening
chickweed
chicory
childish
chilly
chintz
chivalrous
chloroform
choirboy
choppier
choppy
chopsticks
choral
christen
chromosomes
chronological
chubbier
chummed
circled
circlets
circularize
circumlocution
circumnavigating
civvies
classicists
cleaners
cleansing
cleanup
clerks
climatologist
climax
climaxes
climber
clinked
clitorises
clogged
clothes
cloudiest
cloying
clubbed
clumsy
clutching
coarsest
coccyxes
coerces
coffee
cognisant
coinages
coincidentally
collaborate
collarbone
collectivizing
collector
colloquial
colonisers
colonnade
colored
colourways
comedienne
commences
commentate
commentating
commercial
commercialism
commercials
commissary
commissioning
commonest
communist
compare
compere
compete
competent
compilation
compiles
complexions
composed
computerised
computes
conceitedly
conceived
concerted
conchies
conclusively
concoctions
concreted
concreting
conducted
confederations
confession
congratulations
congressman
conical
conjectures
connect
connubial
conquering
consents
consoled
consolidations
consort
conspicuousness
constantly
container
contention
contentment
contestants
contextualised
contextualises
continuance
contradiction
contraindications
contribution
controversial
conversations
conviction
convulsing
coolie
cooped
coordinating
copula
copycats
copywriter
coracles
coreligionists
corncobs
corncrake
cornstarch
correspondent
corrie
corroborative
corrupted
cosmopolitans
cossetting
cottages
cottoning
couchettes
cougar
counteracts
countless
courageously
courtliness
courtyard
cracker
crackers
craning
cranky
cranny
creakily
creakiness
creators
credit
crescent
crewed
criminalizes
criminalizing
crispness
crocks
crossbones
crosschecks
croupiers
crowded
crucifying
cruder
crumpet
crumple
crystallisation
crystallising
cumming
curacies
curliness
currant
cursive
curtseyed
cutouts
cyclical
cylinders
cypher
daises
dammit
damnable
danced
dastardly
dawdling
deafened
dearests
debates
debenture
debriefs
debunked
decanted
decanter
deception
decimates
decisiveness
decriminalize
dedication
deductions
defeatist
defeatists
defecate
deferment
define
deflates
deformity
defraud
defrosters
defrosting
dehumanising
deigning
deletions
delineating
delved
demand
democratisation
demographer
demolished
demoniacal
denationalizes
denial
denigrating
densely
denseness
denude
deodorising
deodorizing
departmental
dependants
depopulate
depress
depressurizes
depute
deranged
derbies
deregulation
descents
desegregation
desolated
despises
destabilizes
destroying
detain
detained
determinants
detestable
detoured
diadem
dialectical
dialectics
diatonic
diciest
dicker
dictatorially
digests
dilute
dingoes
disagreeably
disagreeing
disagreements
discernible
disciplinarians
discoloring
discomfited
discoverers
discredit
discreetly
discrimination
disembodied
disequilibrium
disguised
disgust
disillusioning
disincentive
disinheriting
disinterested
dislodges
disobey
disobeyed
disoriented
dispatches
dispersed
disposal
disprove
disregard
disrupts
dissembled
dissociation
distaste
distend
distinctions
distributorships
disturbing
disunited
dividends
divines
dizzying
dodders
dogleg
doglegs
dogmatist
dolling
dominions
donating
dormers
dormitories
doubts
downers
downgrading
downstairs
dowsing
drachmae
draconian
draftier
drained
drainpipe
dropper
droppings
droughts
drugstore
drumming
duplication
earthed
earthquake
economised
educates
effacing
efficiently
elaborately
elderberries
elected
electrically
electrodes
electromagnets
elision
eloped
elucidate
elucidating
embassy
embezzling
emboss
emergence
emperor
emperors
emptied
enables
encampments
enchanted
enchilada
encircling
encumbering
endeavored
endemic
endocrine
endurance
energies
enervated
enfold
enfolds
engagement
engineering
engraves
enhancers
enlightened
enormously
ensconces
enshrouds
enslaves
ensnare
entirety
entrenchments
epicentre
epidermis
epiphany
epistolary
equivocal
equivocations
eradicates
eroded
errors
escape
esoteric
espies
espying
essaying
ethical
ethnologically
evacuated
evaluated
evaluation
evasion
evicting
evilly
evocations
evolves
exacerbated
exactness
excavations
exchanged
exclaiming
exclude
exclusionary
excoriate
excreting
excusing
exhortations
exigency
expectation
expects
experts
expiates
expiring
explored
explorers
expostulation
extends
exterminates
externalised
externalizes
extinct
extolling
extradites
extraterrestrial
eyeful
eyeing
eyeliner
facelift
facilitates
faffed
faintest
fairyland
faithlessly
falsifications
familiarize
fanatic
fanaticism
fandangos
fantasise
fanzines
farmhouses
fascists
fatigues
favored
favorite
favourite
fazing
featherbrained
feeblest
feeder
feelgood
feints
ferociousness
fibulae
fictionalisation
fictionalisations
fidgets
finales
finder
finders
finesses
firmer
fishermen
fishiest
fissures
fitment
fitters
fjords
flagellate
flagellation
flapjacks
flautists
flavouring
flicker
flightier
flosses
flotillas
flounce
flouncing
flunkeys
fluoridating
fodder
folders
footsteps
footstools
forays
forbearance
forewarns
forking
formalizing
formals
forsythias
fractals
frames
franchisee
fraternises
fraudulent
freakiest
freebooter
freighted
frenzy
freshening
fresher
fretting
frizzy
frontiersmen
frugally
frumpiest
fuelled
fulfilled
fulness
functionalists
funiculars
furnished
fusilier
futurists
futurity
gadgets
gallivanted
gallon
gambols
gamekeeper
gangsta
garcons
gardens
gasolene
gatecrashes
gaudily
gawking
generates
genial
genning
gentrification
germinating
ghettoizing
gimmick
glamor
glassful
glaziers
globalizing
globetrotters
gloves
glowering
gluttony
goatherd
godless
godmother
godson
goldfinch
golfing
gooiest
gooseberries
gooseflesh
gorgeous
grabby
gramophone
gramophones
grandads
granular
graphite
grapnel
grasses
graters
gratins
greats
greenfield
greenhouse
griddle
grouch
groundskeeper
groundskeepers
growls
guarantees
guesswork
gunnels
gynecologist
habitable
hacking
hairiest
hairline
handguns
handkerchiefs
handrails
hangdog
happens
happiest
harbor
harbour
harboured
hardwood
harlequins
harnesses
harpsichord
hashing
hastens
hatbox
hatter
haulage
haulier
hawkers
headache
headers
headhunt
headhunted
headmistress
health
heartaches
hearthrugs
hemorrhaging
hesitations
heuristic
hideous
hideout
hinted
hippos
hitched
hitches
hitchhikers
holidaymakers
homburg
homeopathic
homesteading
homeworker
homogenising
honchos
honeysuckle
hoodwink
horses
horticultural
hotplates
housemasters
housemistress
housewarmings
housewifely
hugging
humanises
humbug
hummock
humored
humpback
hunkering
hurricane
husbandry
hydrates
hyperventilated
iambic
idealistic
identikit
idolizes
ignitions
illuminate
illusory
imagining
imbued
immunizes
immure
imparted
impasse
impassivity
impersonated
implanting
implosions
importers
impound
impoverishment
improvement
impudence
impulsiveness
impure
inactivity
inamorata
incapacitate
incarnates
inclusions
incongruities
inconspicuously
increased
incremental
incubated
incurious
indebted
indemnities
indies
indoctrinate
indoctrinates
indubitably
inductees
industrialisation
inexpedient
inexpensively
inferior
infiltrator
informally
ingested
ingrowing
inhibited
inklings
inmate
innuendos
inoculation
inpatients
inputted
inquiring
inquisition
insipid
insisted
insisting
inspects
insteps
instigates
instills
insured
intellectualism
intense
interbreeding
interchangeable
interconnected
interesting
interfere
interlaced
intermediates
interned
interpreted
interwove
intestine
intrinsically
introspection
inventor
investitures
invigorating
ionosphere
ironmongery
irradiated
irreparably
irreproachable
issues
itemise
itemised
jackasses
jackhammers
jaguar
jammed
jangles
javelins
jazzing
jealously
jeopardising
jesting
jettisons
jewelers
journo
joylessness
jubilant
juntas
justices
keepsakes
kennels
kenning
keyboard
kingmaker
kinkiest
kinship
kneecaps
knocker
knockers
laborer
lacerate
lactic
lampreys
landholder
landscapes
larkspurs
laughably
launcher
laundry
laxest
layover
laziest
leaned
leaseback
leering
legible
legislates
legitimises
lessons
letting
levitated
liberal
liberalize
liberator
licences
lieutenant
likely
lionizing
lipstick
liquidized
listenable
livened
loafer
lollop
lovable
lucked
luggage
lugubrious
lugubriously
luncheonette
lychgate
mackerel
madams
maggot
magnets
magnolia
maidens
mainsails
majorette
majority
makeweights
malfunction
malfunctioned
mammogram
manacles
managed
manana
manipulating
manpower
mansards
margarine
marginalisation
marginalizing
marketeer
marking
maroon
marquesses
marshland
marten
martinis
masculinity
matricide
maximize
mayoral
maypoles
meandered
meanness
medicinal
melodrama
melodramatic
member
memoranda
mentors
mercilessly
merino
mescalin
mesmerizing
metabolise
metabolisms
meters
microwaveable
miffed
mileometer
mileometers
millipede
milometer
minarets
minestrone
miniaturises
mirages
miscarriages
misconstrued
miscreants
misdirected
miserly
misjudged
mislead
misogynistic
mispronounces
mistaking
mistress
misunderstanding
mobilise
mockingbirds
modeled
moderate
moderators
moisturizers
moisturizes
molecule
mollycoddle
mollycoddles
molten
monolith
monoplanes
monopolised
monotone
monotonous
monotonously
moonlit
moping
mordantly
morphs
mortice
motorists
mounds
mountaintop
mouthwash
mulberries
mulching
mullahs
multiplexes
multiplies
mundane
munificent
murders
murkier
musher
musicians
mussel
mustang
mustering
mutilating
mutilations
mutuality
mutually
nailing
narcoleptic
narration
national
nauseous
neater
necklace
neckties
needier
nefarious
negate
neglect
neighing
nepotism
neurologist
newspaperman
nimbler
nipple
nitrogen
nitwits
normalise
northbound
nutcrackers
nuttiest
nymphet
oarsmen
oarswoman
oatcakes
obedient
objectively
objects
obligation
obliging
obliteration
oblivious
observatories
obsessions
obstructions
occupying
offertories
offertory
officiating
officiousness
offload
offside
omelet
omission
ontology
opaquely
opener
operable
operations
oppression
oppressor
optimise
optimises
optimum
oratory
ordinariness
ordnance
organisation
organisms
organizing
orthodoxies
oscillators
otters
outbreaks
outcries
outmaneuver
outrages
outweighed
overacted
overbalances
overcomes
overeating
overestimated
overladen
overprotective
overreached
overreacted
overruling
overshadowed
oversleeps
overspends
overtake
overtaxes
overtaxing
overturn
overvaluation
overwriting
oxidation
oxidizes
padding
pageant
paginates
painters
paired
paleontologists
palpates
panhandler
panorama
pantechnicons
papayas
paracetamols
paramedical
paramedics
paranoids
paratrooper
pardoned
parishioners
parities
parody
partaken
partaking
participles
particularity
parting
partitioned
partridge
passivised
password
pasteurizing
patches
patching
patriots
patronesses
patronized
patters
pausing
payroll
payslips
peccadillos
peevishness
peewee
pellucid
penalise
penciled
perfectionists
performances
performer
permissions
personages
personifications
pervasively
peskiest
petrodollars
petticoat
pharmacopoeias
pheasant
phenom
philological
phlegm
photoelectric
photostatted
physical
physiognomies
physiology
physios
physiotherapists
piazza
pickaxe
pickiest
pickled
pickling
picnickers
piffling
pigpens
pimientos
pinholes
pinnies
pioneered
piousness
pirouetted
pirouetting
pitching
pitiless
plaintive
plantings
platitude
playthings
pleadingly
pledges
plummets
plumping
plundering
plunge
pockmark
pokier
polarized
policed
politic
politics
polity
pollster
polygamy
polyglot
polymaths
polysemous
poncho
poncing
ponied
poppets
portions
portrayals
poseur
posher
possessors
postboxes
posters
postmark
postseason
postulated
potent
powders
practiced
practices
pranksters
prattle
preaching
preambles
precedence
precepts
predestination
predictors
preferring
premenstrual
premise
prepacked
prerequisites
prescient
prescribed
presents
president
presidents
presumes
prettifies
prevaricate
prided
primes
princes
printout
prioritise
prisoners
prissier
privacy
prizewinning
problem
proclivity
procreating
produce
professionalize
profundity
progressing
progressions
prolific
prominently
promises
promising
prompters
pronounce
prophecy
proposers
propounded
proprietresses
prosecutions
prostrated
protesting
protrusions
proudest
proviso
pruning
pseudonym
psychoses
psychotherapist
psychotherapists
publication
publicises
puddles
pulpits
pulsing
pummeled
pumped
pumpkin
puppies
purchaser
purchasers
pursers
purveys
pusillanimous
puzzle
pyramid
pyromaniac
quadruples
qualms
quarreled
quashes
question
questioningly
quicken
quicksilver
quieten
quintet
quirkier
quizzical
quotient
qwerty
rabbited
racketeer
radiance
ramblings
ramshackle
rangefinders
rangers
raping
rarely
raspberry
ratchet
ratcheted
rationalises
ratting
reactionaries
realized
reasserts
rebelliousness
recant
recapitulation
recaps
recharged
recognized
reconciliation
reconvene
record
records
recriminatory
rectitude
recycling
redoes
redounding
redresses
referencing
reflections
reflexive
reflexology
refurbishes
refusals
regarding
regards
regents
regretful
rehearse
rehoused
reiterates
relapse
relaunching
relies
religions
reloaded
relocated
remarriages
remaster
rematch
reminding
remodelling
remolding
repenting
repetitively
replicate
repressing
reprint
reproached
reproves
reruns
rescues
resemble
reserve
resettles
resonated
resounds
respired
resplendence
restarting
restocked
restraints
resurfaces
retrenches
retrogression
retrospective
returnable
returning
reusable
reverential
reversals
reversibility
revisionist
revisions
revivalist
revolted
revolutions
revolving
rewires
rhinestone
rhymes
rickets
ricocheted
ridges
rigged
rightist
ringlet
robbed
rocketing
rocking
rococo
rolling
rostra
rostrum
rouses
rowdily
rubber
rubbers
ruinous
rumbles
rumination
rumpled
runways
rushing
saboteurs
sackful
sackings
sacrilegious
sacristy
salamander
salesclerks
salvoes
samosa
sampans
samples
sanctioning
sandbank
sandpit
sarcophagus
satisfactorily
satisfies
savageries
savages
saving
scales
scamper
scandalous
scapegoating
scarabs
scarpering
scenarios
schnook
scholarly
schoolmarmish
schoolyard
scolding
scorching
scratches
screwed
scribbling
scrimped
scrolls
scrounging
scruffiness
scruple
scudded
scuppered
seamier
searchers
secure
seesawing
segments
seizures
senators
sensor
sententious
sentimentalises
sequentially
series
sermonised
sermonize
serviced
setsquare
seventeenths
severally
shallots
shattering
shavers
sheathe
shebeens
sheepishness
shelling
shepherding
shibboleths
shinned
shipment
shipped
shippers
shortage
shortbread
shorthanded
shorty
showdowns
shrink
shrinking
shrubs
shutdowns
sickens
sidekick
signposting
silvan
simplifications
singed
singulars
sinister
sisterhood
skateboarder
skater
skewer
skimps
skyjack
skyrocketing
slagged
slammed
slappers
slaughter
slaughtering
slavery
sleepiness
slipways
slouches
slowdown
smacking
smiling
smoothness
smugly
smuttiest
snooper
snooty
snorkelling
snowmobile
snuffed
sociables
socials
sociologically
softback
softens
solicitors
sombrero
something
songster
songwriter
soothingly
sophomore
sorrowful
sorrows
spacewoman
spammed
spankings
spareribs
sparring
speedometer
sphincters
sphinx
spiciness
spindly
spinneys
splattered
spluttered
spookier
spotters
spouts
sprayers
spraying
springing
spurted
sputters
squirreled
stabbing
stablemen
staffers
stains
stairwell
stalled
stance
stanch
standardisation
starchiest
stares
starlings
starter
statesmen
staunching
staving
steamed
steeplejacks
stepchild
stereo
stereotypes
stickier
stickleback
stilted
stockbroking
straddles
stranglers
strategy
strictest
strives
strongmen
studious
stuffily
stumps
stunting
sturdiest
subcutaneously
subdue
subduing
subjectivity
subordination
substantially
substitutes
subtotals
subversively
suction
suctions
suffocation
suffrage
suggestible
sullied
sultana
sunblock
sundae
sundials
sunglasses
superconductor
supersedes
superstar
superstitious
superstructure
suppository
suppurated
sureness
surrounded
susceptibilities
suspecting
susses
suzerainty
swaddled
swamps
swearing
sweatbands
sweatpants
sweatsuits
sweetmeats
swiftly
swirling
switched
swivelled
swooning
sycophantic
symbolises
symposia
synchronizing
syndicalists
syphons
systematically
tableware
tackled
tackling
tactlessness
tadpole
tailcoat
tailpieces
tailpipe
takeaway
takings
tamoxifen
tangerines
tantalised
tantalize
tapirs
tappets
tardier
tarmac
tautens
taxicab
teachers
tearaways
teasel
teaspoon
teazle
technicalities
technicality
technologies
technologists
teemed
teepee
teetotal
tellies
temporising
tenaciously
tenants
tepees
termites
terrier
tester
testicular
testily
testimonial
theocratic
thicken
thickeners
thingummy
thistles
thrill
thrive
throatily
thronged
thunders
tickled
tickles
tidiest
tidying
tiebreak
tiebreaker
timeliest
timetables
timidly
tinder
tinkers
tinkling
tiresome
tissue
toadied
toastmaster
toboggan
tonier
toothy
topographically
topples
torpedo
torturers
toting
touchlines
traced
tracers
tracheas
trackball
trafficked
trainspotting
transcendental
transfixed
transience
transistor
transitives
translator
translators
transliterations
transmogrifies
transparent
trappings
traumatizes
trembles
trendsetter
triangular
triangulation
tribunals
trickle
tridents
trinkets
truces
truncheons
trunks
trussed
trying
tumbles
turbocharges
tussling
typing
umlaut
umpire
umpiring
unarguable
unattached
unbiased
unchanging
uncompromising
unconsidered
underachievement
undercharge
underdone
underestimating
undergone
undergrowth
underpass
underscoring
undersells
undersized
understate
underwater
undisciplined
undressed
unequaled
unfathomable
unfavourable
unforeseeable
unhitch
uniformity
unisex
unloads
unmolested
unpredictable
unprotected
unravel
unrelieved
unrelievedly
unremitting
unscramble
unscrambling
unscrewed
unsophisticated
unstructured
unsuitable
untangle
untutored
unwraps
upstairs
uselessly
ushered
usurpation
utilised
utilized
uttered
vacancy
vaccinating
vacuuming
vagueness
vandalised
vantage
vaporization
variant
vaulted
vegetarian
vegges
veggieburger
ventriloquist
verbalised
verbatim
versos
veterinary
vibrators
victims
videophones
videotape
videotapes
vigils
villainy
violincellos
virgin
viscera
visitation
vitiates
vocabulary
volumes
vouchsafe
wainscots
waiting
waltzed
wanderer
wanderers
wapiti
warped
warthog
waster
wastrels
waterfowl
waterproofing
wattle
waylays
weatherman
wedding
weedkiller
weekend
weevil
weighbridges
weirdest
welches
wellness
westernise
whales
wheelies
wheezy
wherewithal
whined
whiskies
whitewashed
wholesalers
wildcatter
wildest
winched
wisterias
withdrawn
wobble
wobbles
womanise
woodsy
workings
workshops
worldliness
worrywart
worsened
worsens
wreaths
wrinklies
writhes
wronging
xenophobia
yachting
yachts
yakking
yodels
youngish
zillions
zonked